# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Management(_AWS):
    _type = "management"
    _icon_dir = "resources/aws/management"


class AutoScaling(_Management):
    _icon = "auto-scaling.png"


class Cloudformation(_Management):
    _icon = "cloudformation.png"


class Cloudtrail(_Management):
    _icon = "cloudtrail.png"


class Cloudwatch(_Management):
    _icon = "cloudwatch.png"


class Codeguru(_Management):
    _icon = "codeguru.png"


class CommandLineInterface(_Management):
    _icon = "command-line-interface.png"


class Config(_Management):
    _icon = "config.png"


class ControlTower(_Management):
    _icon = "control-tower.png"


class LicenseManager(_Management):
    _icon = "license-manager.png"


class ManagedServices(_Management):
    _icon = "managed-services.png"


class ManagementConsole(_Management):
    _icon = "management-console.png"


class Opsworks(_Management):
    _icon = "opsworks.png"


class Organizations(_Management):
    _icon = "organizations.png"


class ServiceCatalog(_Management):
    _icon = "service-catalog.png"


class SystemsManagerParameterStore(_Management):
    _icon = "systems-manager-parameter-store.png"


class SystemsManager(_Management):
    _icon = "systems-manager.png"


class TrustedAdvisor(_Management):
    _icon = "trusted-advisor.png"


class WellArchitectedTool(_Management):
    _icon = "well-architected-tool.png"


# Aliases

SSM = SystemsManager
ParameterStore = SystemsManagerParameterStore
