# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Logging(_OnPrem):
    _type = "logging"
    _icon_dir = "resources/onprem/logging"


class Fluentd(_Logging):
    _icon = "fluentd.png"


class Logstash(_Logging):
    _icon = "logstash.png"


# Aliases

LogStash = Logstash
