# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OCI


class _Security(_OCI):
    _type = "security"
    _icon_dir = "resources/oci/security"


class AuditGrey(_Security):
    _icon = "audit-grey.png"


class Audit(_Security):
    _icon = "audit.png"


class CompartmentsGrey(_Security):
    _icon = "compartments-grey.png"


class Compartments(_Security):
    _icon = "compartments.png"


class DdosGrey(_Security):
    _icon = "ddos-grey.png"


class Ddos(_Security):
    _icon = "ddos.png"


class EncryptionGrey(_Security):
    _icon = "encryption-grey.png"


class Encryption(_Security):
    _icon = "encryption.png"


class GroupsGrey(_Security):
    _icon = "groups-grey.png"


class Groups(_Security):
    _icon = "groups.png"


class IdAccessGrey(_Security):
    _icon = "id-access-grey.png"


class IdAccess(_Security):
    _icon = "id-access.png"


class KeymgmtGrey(_Security):
    _icon = "keymgmt-grey.png"


class Keymgmt(_Security):
    _icon = "keymgmt.png"


class OcidGrey(_Security):
    _icon = "ocid-grey.png"


class Ocid(_Security):
    _icon = "ocid.png"


class PoliciesGrey(_Security):
    _icon = "policies-grey.png"


class Policies(_Security):
    _icon = "policies.png"


class TaggingGrey(_Security):
    _icon = "tagging-grey.png"


class Tagging(_Security):
    _icon = "tagging.png"


# Aliases
